@@ -383,17 +383,14 @@ def nlu_train_model(
     project_id: Text, language: Text, model_name: Text, wait: bool, wait_interval: int
 ):
 
-    if project_id and language:
-        print_logo()
-        if model_name is None:
-            model_name = randomname.get_name(**NAME_GENERATOR_CONFIG)
-        loop = asyncio.new_event_loop()
-        loop.run_until_complete(
-            train_model(project_id, language, model_name, wait, wait_time=wait_interval)
-        )
-        loop.run_until_complete(get_async_http_session().close())
-    else:
-        list_projects()
+    print_logo()
+    if model_name is None:
+        model_name = randomname.get_name(**NAME_GENERATOR_CONFIG)
+    loop = asyncio.new_event_loop()
+    loop.run_until_complete(
+        train_model(project_id, language, model_name, wait, wait_time=wait_interval)
+    )
+    loop.run_until_complete(get_async_http_session().close())
 
 
 @nlu.command(name="model-status")
